<?php

namespace Drupal\blizz_vanisher\Service;

/**
 * Class DailymotionVanisherVanisher.
 *
 * @package Drupal\blizz_vanisher\Service
 */
class DailymotionVanisher extends EmbeddedVideoVanisher {

  /**
   * The regular expression to find the video id inside of a dailymotion url.
   *
   * @see https://stackoverflow.com/a/9102270/2779907
   */
  const DAILYMOTION_VIDEO_ID_REGEX = '~^.*(dailymotion\.com\/|v\/|u\/\w\/|embed\/video\/|watch\?v=|\&v=)([^#\&\?]*).*~i';

  /**
   * {@inheritdoc}
   */
  protected function getReplacementMarkupTemplate() {
    return '<div class="dailymotion_player" videoID="@video_id" width="@width" height="@height"></div>@info_text';
  }

  /**
   * {@inheritdoc}
   */
  protected function getIframeSearchRegexPattern() {
    return '~(<iframe[^>]*?src=[^>]*?dailymotion.*?>.*?</iframe>)~is';
  }

  /**
   * {@inheritdoc}
   */
  protected function getReplacementScript() {
    return '(tarteaucitron.job = tarteaucitron.job || []).push(\'dailymotion\');';
  }

  /**
   * {@inheritdoc}
   */
  protected function getVideoData($markup) {
    $data = parent::getVideoData($markup);
    $data['video_id'] = $this->extractVideoId($data['src']);

    return $data;
  }

  /**
   * Extracts the video id.
   *
   * @param string $url
   *   The video url containing the video id.
   *
   * @return string|null
   *   The video id or NULL.
   */
  protected function extractVideoId($url) {
    $matches = array();
    $ret = preg_match(self::DAILYMOTION_VIDEO_ID_REGEX, $url, $matches);
    if ($ret != FALSE && $ret == 1) {
      return $matches[2];
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getVanisherName() {
    return 'dailymotion_vanisher';
  }

  /**
   * {@inheritdoc}
   */
  public function __toString() {
    return 'Dailymotion Vanisher';
  }

}
